Utilities
*********

This section shows general objects and helper functions that are used with this package.

Drivers
=======

.. autoclass:: balderhub.selenium.lib.utils.drivers.BaseSeleniumDriver
    :members:

.. autoclass:: balderhub.selenium.lib.utils.drivers.SeleniumChromeDriver
    :members:

.. autoclass:: balderhub.selenium.lib.utils.drivers.SeleniumEdgeDriver
    :members:

.. autoclass:: balderhub.selenium.lib.utils.drivers.SeleniumFirefoxDriver
    :members:

.. autoclass:: balderhub.selenium.lib.utils.drivers.SeleniumIEDriver
    :members:

.. autoclass:: balderhub.selenium.lib.utils.drivers.SeleniumRemoteDriver
    :members:

.. autoclass:: balderhub.selenium.lib.utils.drivers.SeleniumSafariDriver
    :members:


WebElementBridges
=================

.. autoclass:: balderhub.selenium.lib.utils.web_element_bridges.SeleniumFullyReidentifiableElementBridge
    :members:

.. autoclass:: balderhub.selenium.lib.utils.web_element_bridges.SeleniumNotReidentifiableElementBridge
    :members:

.. autoclass:: balderhub.selenium.lib.utils.web_element_bridges.SeleniumPartlyReidentifiableElementBridge
    :members:

.. autoclass:: balderhub.selenium.lib.utils.web_element_bridges.SeleniumWebElementBridge
    :members:

Further Utilities
=================

.. autoclass:: balderhub.selenium.lib.utils.Selector
    :members:
